# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .bonded_network import *
from .cloud_config import *
from .get_cloud_config import *
from .get_host import *
from .get_hosts import *
from .get_network import *
from .get_pif import *
from .get_pool import *
from .get_resource_set import *
from .get_sr import *
from .get_template import *
from .get_user import *
from .get_vdi import *
from .get_vms import *
from .get_xoa_cloud_config import *
from .get_xoa_host import *
from .get_xoa_hosts import *
from .get_xoa_network import *
from .get_xoa_pif import *
from .get_xoa_pool import *
from .get_xoa_resource_set import *
from .get_xoa_storage_repository import *
from .get_xoa_template import *
from .get_xoa_user import *
from .get_xoa_vdi import *
from .get_xoa_vms import *
from .network import *
from .provider import *
from .resource_set import *
from .vdi import *
from .vm import *
from .xoa_bonded_network import *
from .xoa_network import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_xenorchestra.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_xenorchestra.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "xenorchestra",
  "mod": "index/acl",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/bondedNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/bondedNetwork:BondedNetwork": "BondedNetwork"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/cloudConfig",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/cloudConfig:CloudConfig": "CloudConfig"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/network",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/network:Network": "Network"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/resourceSet",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/resourceSet:ResourceSet": "ResourceSet"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/vdi",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/vdi:Vdi": "Vdi"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/vm",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/vm:Vm": "Vm"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/xoaBondedNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/xoaBondedNetwork:XoaBondedNetwork": "XoaBondedNetwork"
  }
 },
 {
  "pkg": "xenorchestra",
  "mod": "index/xoaNetwork",
  "fqn": "pulumi_xenorchestra",
  "classes": {
   "xenorchestra:index/xoaNetwork:XoaNetwork": "XoaNetwork"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "xenorchestra",
  "token": "pulumi:providers:xenorchestra",
  "fqn": "pulumi_xenorchestra",
  "class": "Provider"
 }
]
"""
)
