# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCloudConfigResult',
    'AwaitableGetCloudConfigResult',
    'get_cloud_config',
    'get_cloud_config_output',
]

warnings.warn("""xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""", DeprecationWarning)

@pulumi.output_type
class GetCloudConfigResult:
    """
    A collection of values returned by getCloudConfig.
    """
    def __init__(__self__, id=None, name=None, template=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if template and not isinstance(template, str):
            raise TypeError("Expected argument 'template' to be a str")
        pulumi.set(__self__, "template", template)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the cloud config you want to look up.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def template(self) -> str:
        """
        The contents of the cloud-config.
        """
        return pulumi.get(self, "template")


class AwaitableGetCloudConfigResult(GetCloudConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudConfigResult(
            id=self.id,
            name=self.name,
            template=self.template)


def get_cloud_config(name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudConfigResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    cloud_config = xenorchestra.get_xoa_cloud_config(name="Name of cloud config")
    ```


    :param str name: The name of the cloud config you want to look up.
    """
    pulumi.log.warn("""get_cloud_config is deprecated: xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('xenorchestra:index/getCloudConfig:getCloudConfig', __args__, opts=opts, typ=GetCloudConfigResult).value

    return AwaitableGetCloudConfigResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        template=pulumi.get(__ret__, 'template'))
def get_cloud_config_output(name: Optional[pulumi.Input[str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudConfigResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_xenorchestra as xenorchestra

    cloud_config = xenorchestra.get_xoa_cloud_config(name="Name of cloud config")
    ```


    :param str name: The name of the cloud config you want to look up.
    """
    pulumi.log.warn("""get_cloud_config is deprecated: xenorchestra.index/getcloudconfig.getCloudConfig has been deprecated in favor of xenorchestra.index/getxoacloudconfig.getXoaCloudConfig""")
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('xenorchestra:index/getCloudConfig:getCloudConfig', __args__, opts=opts, typ=GetCloudConfigResult)
    return __ret__.apply(lambda __response__: GetCloudConfigResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        template=pulumi.get(__response__, 'template')))
